##' conversion function
##'
##' unit conversion
##' @title e2l
##' @param energy in eV
##' @return wavelength in nm
##' @export
##' @family user_level conversion utility
##' @author baptiste Auguie
e2l <- function(energy)
  with(dielectric::constants, 1e9*h * cel / ee / energy)

##' conversion function
##'
##' unit conversion
##' @title l2e
##' @param wavelength in nm
##' @return energy in eV
##' @export
##' @family user_level conversion utility
##' @author baptiste Auguie
l2e <- function(lambda)
  with(dielectric::constants, 1e9*h * cel / ee / lambda)

##' polarizability
##'
##' lorentzian polarizability of a molecule/QD
##' @title polarizability_dye
##' @param wavelength in nm
##' @param lambda_0 in nm
##' @param lambda_0 in nm
##' @param alpha_0 in nm3
##' @param alpha_inf in nm3
##' @return polarizability in nm3
##' @export
##' @family user_level utility
##' @author baptiste Auguie
polarizability_dye <- function(wavelength, lambda_0=950,
                               mu_0=100000,
                               alpha_0=3.9e-39*1e27,
                               alpha_inf=2.2e-39*1e27, ...){
  
  alph <- alpha_0 / (1 - (lambda_0 / wavelength)^2 -1i*lambda_0^2 / 
                       (mu_0*wavelength)) + alpha_inf
  epsilon_0 <- 8.854e-12
  alph / epsilon_0
}

##' clausius_mossotti
##'
##' lorentzian polarizability of a molecule
##' @title clausius_mossotti
##' @param alpha in nm3
##' @param N in nm-3
##' @return relative dielectric function
##' @export
##' @family user_level utility
##' @author baptiste Auguie
clausius_mossotti <- function(alpha =1, N=1e-1)
  (2*N*alpha + 1) / (1 - N*alpha)

##' epsilon_qd
##'
##' dielectric function representing a quantum dot
##' @title epsilon_qd
##' @param wavelength in nm
##' @param ... passed to polarizability_dye
##' @return dielectric function
##' @export
##' @family user_level utility polarizability
##' @author baptiste Auguie
epsilon_qd <- function(wavelength, ...)
  clausius_mossotti(polarizability_dye(wavelength, ...))
